@@ -2,7 +2,22 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2011 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2010 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2009 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2008 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2007 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2006 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -105,7 +120,7 @@ extern "C" {
 
 
 #define __MIN_OFFSET(bits)  1
-#define __MAX_OFFSET(bits)  LZO_SIZE(bits)
+#define __MAX_OFFSET(bits)  LZO_LSIZE(bits)
 
 #define M1_MIN_OFFSET       __MIN_OFFSET(M1X_BITS)
 #define M2_MIN_OFFSET       __MIN_OFFSET(M2X_BITS)
@@ -326,5 +341,7 @@ extern "C" {
 
 #endif /* already included */
 
+/*
+vi:ts=4:et
+*/
 
-/* vim:set ts=4 sw=4 et: */
